==> nextcloud-11.0.2.tgz: nextcloud/apps/encryption/l10n/zh_TW.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "遺失還原金鑰密碼",
    "Please repeat the recovery key password" : "請您再輸入新的還原金鑰密碼一次",
    "Repeated recovery key password does not match the provided recovery key password" : "輸入的還原金鑰密碼與設定的並不相符",
    "Recovery key successfully enabled" : "還原金鑰已成功開啟",
    "Could not enable recovery key. Please check your recovery key password!" : "無法啟用還原金鑰。請檢查您的還原金鑰密碼!",
    "Recovery key successfully disabled" : "還原金鑰已成功停用",
    "Could not disable recovery key. Please check your recovery key password!" : "無法停用還原金鑰。請檢查您的還原金鑰密碼!",
    "Missing parameters" : "遺失參數",
    "Please provide the old recovery password" : "請提供舊的還原密碼",
    "Please provide a new recovery password" : "請提供新的還原密碼",
    "Please repeat the new recovery password" : "請您再輸入新的還原密碼",
    "Password successfully changed." : "成功變更密碼。",
    "Could not change the password. Maybe the old password was not correct." : "無法變更密碼，或許是輸入的舊密碼不正確。",
    "Recovery Key disabled" : "還原金鑰停用",
    "Recovery Key enabled" : "還原金鑰啟用",
    "Could not enable the recovery key, please try again or contact your administrator" : "無法啟用還原金鑰功能，請重試或聯絡系統管理員",
    "Could not update the private key password." : "無法更新私人金鑰密碼",
    "The old password was not correct, please try again." : "舊密碼不正確，請再試一次",
    "The current log-in password was not correct, please try again." : "目前登入的密碼不正確，請再試一次",
    "Private key password successfully updated." : "私人金鑰密碼已成功更新。",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "您需要搬移您的加密鑰匙從舊版的加密 (ownCloud <= 8.0) 到新版，請執行 'occ encryption:migrate' 或是聯絡系統管理員",
    "Bad Signature" : "壞的簽章",
    "Missing Signature" : "遺失簽章",
    "one-time password for server-side-encryption" : "一次性密碼用於伺服器端的加密",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請詢問檔案所有人重新分享檔案給您。",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法檢視這個檔案，或許這是分享的檔案，請詢問這個檔案的擁有者並請他重新分享給您。",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "嗨，請看這裡，\n\n系管理員啟用了伺服器端的加密功能，您的檔案將會使用密碼 '%s' 加密\n\n請從網頁登入，到 'basic encryption module' 設置您的個人設定並透過更新加密密碼，將這個組密碼設定在 'old log-in password'  以及您的目前登入密碼\n",
    "The share will expire on %s." : "這個分享將會於 %s 過期",
    "Cheers!" : "太棒了！",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "嗨，請看這裡，<br><br>系管理員啟用了伺服器端的加密功能，您的檔案將會使用密碼<strong> '%s' </strong>加密，請從網頁登入，到 'basic encryption module' 設置您的個人設定並透過更新加密密碼，將這個組密碼設定在 'old log-in password'  以及您的目前登入密碼<br><br>",
    "Encrypt the home storage" : "加密家目錄空間",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "請啟用這個功能以用來加密主要儲存空間的檔案，否則只有再外部儲存的檔案會加密",
    "Enable recovery key" : "啟用還原金鑰",
    "Disable recovery key" : "關閉還原金鑰",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "加密金鑰是另一種加密檔案方式，當使用者忘記密碼時，可以用還原金鑰來還原檔案",
    "Recovery key password" : "還原金鑰密碼",
    "Repeat recovery key password" : "再輸入還原金鑰密碼一次",
    "Change recovery key password:" : "變更還原金鑰密碼:",
    "Old recovery key password" : "舊的還原金鑰密碼",
    "New recovery key password" : "新的還原金鑰密碼",
    "Repeat new recovery key password" : "再輸入新的還原金鑰密碼一次",
    "Change Password" : "變更密碼",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "檔案加密已啓用，但是您的金鑰尚未初始化，請重新登入一次",
    "Your private key password no longer matches your log-in password." : "您的私人金鑰密碼不符合您的登入密碼",
    "Set your old private key password to your current log-in password:" : "設定您的舊私人金鑰密碼到您現在的登入密碼:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "如果您忘記舊密碼，可以請求管理員協助取回檔案。",
    "Old log-in password" : "舊登入密碼",
    "Current log-in password" : "目前的登入密碼",
    "Update Private Key Password" : "更新私人金鑰密碼",
    "Enable password recovery:" : "啟用密碼還原:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "啟用這個選項將會允許您因忘記密碼但需要存取您的加密檔案",
    "Enabled" : "已啓用",
    "Disabled" : "已停用"
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.1.tgz: nextcloud/apps/encryption/l10n/zh_TW.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "遺失還原金鑰密碼",
    "Please repeat the recovery key password" : "請您再輸入新的還原金鑰密碼一次",
    "Repeated recovery key password does not match the provided recovery key password" : "輸入的還原金鑰密碼與設定的並不相符",
    "Recovery key successfully enabled" : "還原金鑰已成功開啟",
    "Could not enable recovery key. Please check your recovery key password!" : "無法啟用還原金鑰。請檢查您的還原金鑰密碼!",
    "Recovery key successfully disabled" : "還原金鑰已成功停用",
    "Could not disable recovery key. Please check your recovery key password!" : "無法停用還原金鑰。請檢查您的還原金鑰密碼!",
    "Missing parameters" : "遺失參數",
    "Please provide the old recovery password" : "請提供舊的還原密碼",
    "Please provide a new recovery password" : "請提供新的還原密碼",
    "Please repeat the new recovery password" : "請您再輸入新的還原密碼",
    "Password successfully changed." : "成功變更密碼。",
    "Could not change the password. Maybe the old password was not correct." : "無法變更密碼，或許是輸入的舊密碼不正確。",
    "Recovery Key disabled" : "還原金鑰停用",
    "Recovery Key enabled" : "還原金鑰啟用",
    "Could not enable the recovery key, please try again or contact your administrator" : "無法啟用還原金鑰功能，請重試或聯絡系統管理員",
    "Could not update the private key password." : "無法更新私人金鑰密碼",
    "The old password was not correct, please try again." : "舊密碼不正確，請再試一次",
    "The current log-in password was not correct, please try again." : "目前登入的密碼不正確，請再試一次",
    "Private key password successfully updated." : "私人金鑰密碼已成功更新。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "無效的加密應用程序私鑰。請在您的個人設定中更新您的私鑰密碼，以恢復對加密文件的訪問。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "已啟用加密應用，但是你的加密密鑰沒有初始化。請重新登出並登入系統一次。",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "請啟用管理員設定中的伺服器端加密，以使用加密模組。",
    "Encryption app is enabled and ready" : "加密應用程式已啟用並準備就緒",
    "Bad Signature" : "壞的簽章",
    "Missing Signature" : "遺失簽章",
    "one-time password for server-side-encryption" : "一次性密碼用於伺服器端的加密",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請詢問檔案所有人重新分享檔案給您。",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法檢視這個檔案，或許這是分享的檔案，請詢問這個檔案的擁有者並請他重新分享給您。",
    "Default encryption module" : "預設加密模組",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "嗨，請看這裡，\n\n系管理員啟用了伺服器端的加密功能，您的檔案將會使用密碼 '%s' 加密\n\n請從網頁登入，到 'basic encryption module' 設置您的個人設定並透過更新加密密碼，將這個組密碼設定在 'old log-in password'  以及您的目前登入密碼\n",
    "The share will expire on %s." : "這個分享將會於 %s 過期",
    "Cheers!" : "太棒了！",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "嗨，請看這裡，<br><br>系管理員啟用了伺服器端的加密功能，您的檔案將會使用密碼<strong> '%s' </strong>加密，請從網頁登入，到 'basic encryption module' 設置您的個人設定並透過更新加密密碼，將這個組密碼設定在 'old log-in password'  以及您的目前登入密碼<br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "已啟用加密應用，但是你的加密密鑰沒有初始化。請重新登出並登入系統一次。",
    "Encrypt the home storage" : "加密家目錄空間",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "請啟用這個功能以用來加密主要儲存空間的檔案，否則只有再外部儲存的檔案會加密",
    "Enable recovery key" : "啟用還原金鑰",
    "Disable recovery key" : "關閉還原金鑰",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "加密金鑰是另一種加密檔案方式，當使用者忘記密碼時，可以用還原金鑰來還原檔案",
    "Recovery key password" : "還原金鑰密碼",
    "Repeat recovery key password" : "再輸入還原金鑰密碼一次",
    "Change recovery key password:" : "變更還原金鑰密碼:",
    "Old recovery key password" : "舊的還原金鑰密碼",
    "New recovery key password" : "新的還原金鑰密碼",
    "Repeat new recovery key password" : "再輸入新的還原金鑰密碼一次",
    "Change Password" : "變更密碼",
    "Basic encryption module" : "基本加密模組",
    "Your private key password no longer matches your log-in password." : "您的私人金鑰密碼不符合您的登入密碼",
    "Set your old private key password to your current log-in password:" : "設定您的舊私人金鑰密碼到您現在的登入密碼:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "如果您忘記舊密碼，可以請求管理員協助取回檔案。",
    "Old log-in password" : "舊登入密碼",
    "Current log-in password" : "目前的登入密碼",
    "Update Private Key Password" : "更新私人金鑰密碼",
    "Enable password recovery:" : "啟用密碼還原:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "啟用這個選項將會允許您因忘記密碼但需要存取您的加密檔案",
    "Enabled" : "已啓用",
    "Disabled" : "已停用",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "您需要搬移您的加密鑰匙從舊版的加密 (ownCloud <= 8.0) 到新版，請執行 'occ encryption:migrate' 或是聯絡系統管理員"
},
"nplurals=1; plural=0;");
